==> msprof_analyze-1.3.2-py3-none-any.whl: profiler/compare_tools/compare_backend/utils/torch_op_node.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
# Copyright (C) 2023-2024. Huawei Technologies Co., Ltd. All rights reserved.
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""

from compare_backend.compare_bean.origin_data_bean.compare_event import MemoryEvent
from compare_backend.compare_bean.origin_data_bean.trace_event_bean import TraceEventBean
from profiler.prof_common.constant import Constant


class TorchOpNode:
    __slots__ = ['_event', '_parent_node', '_child_nodes', '_kernel_list', '_kernel_num', '_memory_allocated_list']

    def __init__(self, event=TraceEventBean, parent_node=None):
        self._event = event
        self._parent_node = parent_node
        self._child_nodes = []
        self._kernel_list = []
        self._kernel_num = 0
        self._memory_allocated_list = []

    @property
    def start_time(self):
        return self._event.start_time

    @property
    def end_time(self):
        return self._event.end_time

    @property
    def name(self):
        return self._event.name

    @property
    def tid(self):
        return self._event.tid

    @property
    def input_shape(self):
        return str(self._event.args.get("Input Dims", Constant.NA))

    @property
    def origin_input_shape(self):
        return self._event.args.get("Input Dims", Constant.NA)

    @property
    def input_type(self):
        return str(self._event.args.get("Input type", Constant.NA))

    @property
    def call_stack(self):
        return str(self._event.args.get("Call stack", Constant.NA))

    @property
    def parent(self):
        return self._parent_node

    @property
    def child_nodes(self):
        return self._child_nodes

    @property
    def kernel_list(self):
        return self._kernel_list

    @property
    def kernel_num(self):
        return self._kernel_num

    @property
    def memory_allocated(self):
        return self._memory_allocated_list

    @property
    def device_dur(self):
        return sum([kernel.device_dur for kernel in self._kernel_list])

    @property
    def api_dur(self):
        return self._event.dur

    @property
    def api_self_time(self):
        return self.api_dur - sum(child.api_dur for child in self._child_nodes)

    def add_child_node(self, child_node):
        self._child_nodes.append(child_node)

    def set_kernel_list(self, kernel_list: list):
        if not kernel_list:
            return
        self._kernel_list.extend(kernel_list)
        kernel_num = len(kernel_list)
        cur_node = self
        while cur_node._parent_node:
            cur_node._kernel_num += kernel_num
            cur_node = cur_node._parent_node

    def update_kernel_list(self, kernel_list: list):
        if not kernel_list:
            return
        self._kernel_list.extend(kernel_list)

    def set_memory_allocated(self, memory_allocated: MemoryEvent):
        self._memory_allocated_list.append(memory_allocated)

    def is_step_profiler(self) -> bool:
        return self._event.is_step_profiler()

    def get_step_id(self) -> int:
        if self.is_step_profiler():
            return int(self._event.name.split("#")[1])
        return Constant.VOID_STEP

    def get_op_info(self) -> list:
        return [self.name, self.input_shape, self.input_type, self.call_stack]

==> msprof_analyze-1.3.4-py3-none-any.whl: profiler/compare_tools/compare_backend/utils/torch_op_node.py <==
# Copyright (c) 2024, Huawei Technologies Co., Ltd.
# All rights reserved.
#
# Licensed under the Apache License, Version 2.0  (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
from compare_backend.compare_bean.origin_data_bean.compare_event import MemoryEvent
from compare_backend.compare_bean.origin_data_bean.trace_event_bean import TraceEventBean

from profiler.prof_common.constant import Constant


class TorchOpNode:
    __slots__ = ['_event', '_parent_node', '_child_nodes', '_kernel_list', '_kernel_num', '_memory_allocated_list']

    def __init__(self, event=TraceEventBean, parent_node=None):
        self._event = event
        self._parent_node = parent_node
        self._child_nodes = []
        self._kernel_list = []
        self._kernel_num = 0
        self._memory_allocated_list = []

    @property
    def start_time(self):
        return self._event.start_time

    @property
    def end_time(self):
        return self._event.end_time

    @property
    def name(self):
        return self._event.name

    @property
    def tid(self):
        return self._event.tid

    @property
    def input_shape(self):
        return str(self._event.args.get("Input Dims", Constant.NA))

    @property
    def origin_input_shape(self):
        return self._event.args.get("Input Dims", Constant.NA)

    @property
    def input_type(self):
        return str(self._event.args.get("Input type", Constant.NA))

    @property
    def call_stack(self):
        return str(self._event.args.get("Call stack", Constant.NA))

    @property
    def parent(self):
        return self._parent_node

    @property
    def child_nodes(self):
        return self._child_nodes

    @property
    def kernel_list(self):
        return self._kernel_list

    @property
    def kernel_num(self):
        return self._kernel_num

    @property
    def memory_allocated(self):
        return self._memory_allocated_list

    @property
    def device_dur(self):
        return sum([kernel.device_dur for kernel in self._kernel_list])

    @property
    def api_dur(self):
        return self._event.dur

    @property
    def api_self_time(self):
        return self.api_dur - sum(child.api_dur for child in self._child_nodes)

    def add_child_node(self, child_node):
        self._child_nodes.append(child_node)

    def set_kernel_list(self, kernel_list: list):
        if not kernel_list:
            return
        self._kernel_list.extend(kernel_list)
        kernel_num = len(kernel_list)
        cur_node = self
        while cur_node.parent:
            cur_node._kernel_num += kernel_num
            cur_node = cur_node.parent

    def update_kernel_list(self, kernel_list: list):
        if not kernel_list:
            return
        self._kernel_list.extend(kernel_list)

    def set_memory_allocated(self, memory_allocated: MemoryEvent):
        self._memory_allocated_list.append(memory_allocated)

    def is_step_profiler(self) -> bool:
        return self._event.is_step_profiler()

    def get_step_id(self) -> int:
        if self.is_step_profiler():
            return int(self._event.name.split("#")[1])
        return Constant.VOID_STEP

    def get_op_info(self) -> list:
        return [self.name, self.input_shape, self.input_type, self.call_stack]
